require "import"
import "android.content.Context"
import "android.os.Vibrator"
import "android.bluetooth.BluetoothAdapter"
import "android.bluetooth.BluetoothDevice"
import "android.bluetooth.BluetoothProfile"
import "android.bluetooth.BluetoothA2dp"
import "android.os.Handler"
import "java.lang.Runnable"

local context = activity or service
local vibrator = context.getSystemService(Context.VIBRATOR_SERVICE)

-- Vibrate if the device has a vibrator
if vibrator.hasVibrator() then
    vibrator.vibrate(200)
end

local bt = BluetoothAdapter.getDefaultAdapter()

-- Function to connect to a Bluetooth device using A2DP profile
local function connectToDevice(deviceName)
    local pairedDevices = bt.getBondedDevices()
    local found = false
    local iterator = pairedDevices.iterator()
    while iterator.hasNext() do
        local device = iterator.next()
        if device.getName() == deviceName then
            found = true
            bt.getProfileProxy(context, luajava.createProxy("android.bluetooth.BluetoothProfile$ServiceListener", {
                onServiceConnected = function(profile, proxy)
                    if profile == BluetoothProfile.A2DP then
                        proxy.connect(device)
                        this.speak(deviceName .. " connection initiated")
                    end
                end,
                onServiceDisconnected = function(profile)
                    -- Handle service disconnected
                end
            }), BluetoothProfile.A2DP)
            break
        end
    end

    if not found then
        this.speak(deviceName .. " is not available. Please try again.")
    end
end

-- Runnable to connect to the device after a delay
local function createRunnable()
    return luajava.createProxy("java.lang.Runnable", {
        run = function()
            connectToDevice("M10")
        end
    })
end

-- Check Bluetooth status and toggle
if bt.isEnabled() then
    bt.disable()
    this.speak("Bluetooth has been disabled")
else
    bt.enable()
    this.speak("Bluetooth has been activated")

    -- Give sufficient time for Bluetooth to enable before attempting to connect
    local handler = Handler()
    handler.postDelayed(createRunnable(), 2000) -- 2-second delay
end

return true